# eric7.MicroPython.EthernetDialogs.IPv4AddressDialog

Module implementing a dialog to enter an IPv4 address.

### Global Attributes

None

### Classes

IPv4AddressDialog | Class implementing a dialog to enter an IPv4 address.

### Functions

None

## IPv4AddressDialog

Class implementing a dialog to enter an IPv4 address.

### Derived from

QDialog, Ui_IPv4AddressDialog

### Class Attributes

None

### Class Methods

None

### Methods

IPv4AddressDialog | Constructor
__updateOk | Private method to update the enabled state of the OK button.
getIPv4Address | Public method to get the entered IPv4 address.

### Static Methods

None

#### IPv4AddressDialog (Constructor)

IPv4AddressDialog(withDhcp=False, parent=None)

Constructor

withDhcp (bool)
  flag indicating to allow the DHCP selection
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### IPv4AddressDialog.__updateOk

__updateOk()

Private method to update the enabled state of the OK button.

#### IPv4AddressDialog.getIPv4Address

getIPv4Address()

Public method to get the entered IPv4 address.

Return:
  tuple containing the IPv4 address, the netmask, the gateway address and the resolver address or the string 'dhcp' if dynamic addressing was selected

Return Type:
  tuple (str, str, str, str) or str

Up